@@ -1,6 +1,6 @@
 # Copyright of the Board of Trustees of Columbia University in the City of New York
 
-import os
+import os, signal
 
 if __name__ == '__main__':
     import sys
@@ -415,11 +415,11 @@ def worker():
 
                 if payload['TI'] == "":
                     server_od_path = SERVER_ANALYZE_PATH / 'inputs' / 'T2_orig_data'
-                    map_name, dicom_path = T2_mapping.main(server_od_path, payload['TR'], payload['TE'],
+                    map_name, dicom_path, np_map_name = T2_mapping.main(server_od_path, payload['TR'], payload['TE'],
                                                            session['patid'])
                 else:
                     server_od_path = SERVER_ANALYZE_PATH / 'inputs' / 'T1_orig_data'
-                    map_name, dicom_path = T1_mapping.main(server_od_path, payload['TR'], payload['TE'], payload['TI'],
+                    map_name, dicom_path, np_map_name = T1_mapping.main(server_od_path, payload['TR'], payload['TE'], payload['TI'],
                                                            session['patid'])
 
                 payload['dicom_path'] = str(dicom_path)
@@ -521,6 +521,9 @@ def launch_virtualscanner():
     """
     app.run(host='0.0.0.0', debug=True)
 
+def kill_virtualscanner():
+    pid = os.getpid()
+    os.kill(pid, signal.SIGTERM)
 
 if __name__ == '__main__':
     launch_virtualscanner()
